@@ -1,12 +1,10 @@
-"""Utility functions around the "input" mechanic."""
-
 # Built-in
 import re
 from typing import Dict
 
 
 def choose_from_dict(choices: Dict) -> str:
-    """The user must choose a value by inputting the associated key."""
+    """User must choose a value by inputting the associated key."""
     # Displays the initial choices
     input_dict = {x: y for (x, y) in choices.items()}
     input_list = sorted(input_dict.keys())
@@ -36,7 +34,7 @@ def input_must_match_regex(regex: str, error_message: str) -> str:
 
 
 def yes_or_no() -> bool:
-    """Forces the users to answer Y or N and returns a bool."""
+    """User must answer yes or now, and it returns a bool."""
     while True:
         answer = input().upper()
         if answer == "Y":
